@@ -109,8 +109,8 @@ void gpx_free_all(gpx_t *gpx) {
 static const char *cache_type_str[] = { "<Unknown>",
   "Traditional Cache|Traditional|Geocache", "Multi-cache|Multi", 
   "Unknown Cache|Other",
-  "Virtual Cache|Virtual", "Webcam Cache|Webcam", "Event Cache|Event",
-  "Letterbox Hybrid", "Earthcache", "Wherigo Cache",
+  "Virtual Cache|Virtual", "Webcam Cache|Webcam", "Event Cache|Event|Geocoins:",
+  "Letterbox Hybrid|Letterbox", "Earthcache", "Wherigo Cache",
   "Mega-Event Cache", "Cache In Trash Out Event",
   ""};
 
@@ -125,7 +125,7 @@ static const char *log_type_str[] = { "<Unknown>",
   "Post Reviewer Note", "Enable Listing", "Publish Listing", "Will Attend", 
   "Attended", "Webcam Photo taken", 
   "Temporarily Disable Listing|Cache Disabled!", 
-  "Needs Maintenance", "Update Coordinates", "Unarchive",
+  "Needs Maintenance", "Update Coordinates", "Unarchive|Archive (show)",
   "Needs Archived", "Archive",
   ""};
 
@@ -134,6 +134,78 @@ static const char *wpt_sym_str[] = { "<Unknown>",
   "Question to Answer", "Trailhead", "Reference Point",
   ""};
 
+#define DLG_DIV 10
+
+/* create the dialog box shown while loading in progress */
+gpx_dialog_t *gpx_busy_dialog_new(GtkWidget *parent) {
+#ifdef USE_MAEMO
+  gpx_dialog_t *dialog = malloc(sizeof(gpx_dialog_t));
+  memset(dialog, 0, sizeof(gpx_dialog_t));
+
+  dialog->dialog = gtk_dialog_new();
+
+  gtk_dialog_set_has_separator(GTK_DIALOG(dialog->dialog), FALSE);
+  gtk_window_set_title(GTK_WINDOW(dialog->dialog), _("Loading..."));
+  gtk_window_set_default_size(GTK_WINDOW(dialog->dialog), 300, 10);
+
+  gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
+  gtk_window_set_transient_for(GTK_WINDOW(dialog->dialog), GTK_WINDOW(parent));
+
+  dialog->label = gtk_label_new("---");
+  gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog->dialog)->vbox), 
+			      dialog->label);
+
+  dialog->pbar = gtk_progress_bar_new();
+  gtk_progress_bar_set_pulse_step(GTK_PROGRESS_BAR(dialog->pbar), 
+				  0.0025 * DLG_DIV);
+
+  gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog->dialog)->vbox), 
+			      dialog->pbar);
+
+  gtk_widget_show_all(dialog->dialog);
+
+  return dialog;
+#else
+  return NULL;
+#endif
+}
+
+void gpx_busy_dialog_destroy(gpx_dialog_t *dialog) {
+  if(!dialog) return;
+
+  gtk_widget_destroy(dialog->dialog);
+  free(dialog);
+}
+
+static void gpx_busy_dialog_progress(gpx_dialog_t *dialog) {
+  static int sub_dlg = 0;
+
+  if(!dialog) return;
+
+  if(sub_dlg++ >= DLG_DIV) {
+    sub_dlg = 0;
+
+    gtk_progress_bar_pulse(GTK_PROGRESS_BAR(dialog->pbar));
+
+    /* wait for main gui to appear */
+    while(gtk_events_pending()) 
+      gtk_main_iteration();
+  }
+}
+
+static void gpx_busy_dialog_set(gpx_dialog_t *dialog, char *name) {
+  if(!dialog) return;
+
+  if(strrchr(name, '/'))
+    name = strrchr(name, '/')+1;
+
+  gtk_label_set_text(GTK_LABEL(dialog->label), name);
+
+  /* wait for main gui to appear */
+  while(gtk_events_pending()) 
+    gtk_main_iteration();
+}
+
 static int str_search(const char *pstr[], char *str, char *type) {
   int i=0;
 
@@ -230,66 +302,6 @@ void gpx_display_all(gpx_t *gpx) {
   }
 }
 
-#if 0
-/* parse loc waypoint entry */
-static void gpx_parse_loc_wpt(gpx_t *gpx, xmlDocPtr doc, xmlNode *a_node) {
-  xmlNode *cur_node = NULL;
-  cache_t **cache = &gpx->cache;
-  
-  /* skip to end of list and create a new entry */
-  while(*cache) 
-    cache = &(*cache)->next;
-
-  *cache = malloc(sizeof(cache_t));
-  memset(*cache, 0, sizeof(cache_t));
-
-  /* set some defaults */
-  (*cache)->type = CACHE_TYPE_UNKNOWN;
-  (*cache)->container = CACHE_CONT_UNKNOWN;
-  (*cache)->available = TRUE;
-  
-  for (cur_node = a_node; cur_node; cur_node = cur_node->next) {
-    if (cur_node->type == XML_ELEMENT_NODE) {
-      char *str;
-
-      if(strcasecmp(cur_node->name, "name") == 0) {
-	(*cache)->name = xmlNodeListGetString(doc, cur_node->children, 1);
-	(*cache)->id = xmlGetProp(cur_node, "id");
-      } else if(strcasecmp(cur_node->name, "link") == 0) {
-	(*cache)->url =  
-	  xmlNodeListGetString(doc, cur_node->children, 1);
-      } else if(strcasecmp(cur_node->name, "type") == 0) {
-	if(str = xmlNodeListGetString(doc, cur_node->children, 1)) {
-	  (*cache)->type = str_search(cache_type_str, str, "cache type");
-	  xmlFree(str);
-	}
-      } else if(strcasecmp(cur_node->name, "coord") == 0) {
-	if((str = xmlGetProp(cur_node, "lat"))) {
-	  (*cache)->pos.lat = g_ascii_strtod(str, NULL);
-	  xmlFree(str);
-	}
-	if((str = xmlGetProp(cur_node, "lon"))) {
-	  (*cache)->pos.lon = g_ascii_strtod(str, NULL);
-	  xmlFree(str);
-	}
-      }
-    }
-  }
-}
-
-/* parse loc entry */
-static void gpx_parse_loc(gpx_t *gpx, xmlDocPtr doc, xmlNode * a_node) {
-  xmlNode *cur_node = NULL;
-
-  for (cur_node = a_node; cur_node; cur_node = cur_node->next) 
-    if (cur_node->type == XML_ELEMENT_NODE) 
-      if(strcasecmp(cur_node->name, "waypoint") == 0) 
-	gpx_parse_loc_wpt(gpx, doc, cur_node->children);
-}
-#endif
-
-/* --------------- stream parser --------------- */
-
 static gint my_strcmp(const xmlChar *a, const xmlChar *b) {
   if(!a && !b) return 0;
   if(!a) return -1;
@@ -671,10 +683,13 @@ static void process_gpx_wpt_gc(xmlTextReaderPtr reader, cache_t *cache) {
 }
 
 /* parse waypoint entry */
-static cache_t *process_gpx_wpt(xmlTextReaderPtr reader, gpx_t *gpx) {
+static cache_t *process_gpx_wpt(xmlTextReaderPtr reader,  gpx_dialog_t *dialog,
+				gpx_t *gpx) {
   char *cmt = NULL, *desc = NULL;
   char *sym = NULL;
 
+  gpx_busy_dialog_progress(dialog);
+
   if(xmlTextReaderIsEmptyElement(reader))
     return NULL;
 
@@ -812,7 +827,8 @@ static cache_t *process_gpx_wpt(xmlTextReaderPtr reader, gpx_t *gpx) {
   return cache;
 }
 
-static void process_gpx(xmlTextReaderPtr reader, gpx_t *gpx) {
+static void process_gpx(xmlTextReaderPtr reader, gpx_dialog_t *dialog, 
+			gpx_t *gpx) {
 
   /* no attributes of interest */
 
@@ -841,7 +857,7 @@ static void process_gpx(xmlTextReaderPtr reader, gpx_t *gpx) {
 			 (strcasecmp(name, "date") == 0))) {
 	xml_get_date(reader, &gpx->year, &gpx->month, &gpx->day);
       } else if(name && strcasecmp(name, "wpt") == 0) {
-	*cache = process_gpx_wpt(reader, gpx);
+	*cache = process_gpx_wpt(reader, dialog, gpx);
 	if(*cache) cache = &(*cache)->next;
       } else {
 	//	printf("something unknown (%s) found\n", name);
@@ -865,8 +881,11 @@ static void process_gpx(xmlTextReaderPtr reader, gpx_t *gpx) {
 }
 
 /* parse loc waypoint entry */
-static cache_t *process_loc_waypoint(xmlTextReaderPtr reader) {
+static cache_t *process_loc_waypoint(xmlTextReaderPtr reader,
+				     gpx_dialog_t *dialog) {
 
+  gpx_busy_dialog_progress(dialog);
+  
   if(xmlTextReaderIsEmptyElement(reader))
     return NULL;
 
@@ -921,7 +940,8 @@ static cache_t *process_loc_waypoint(xmlTextReaderPtr reader) {
   return NULL;
 }
 
-static void process_loc(xmlTextReaderPtr reader, gpx_t *gpx) {
+static void process_loc(xmlTextReaderPtr reader, gpx_dialog_t *dialog, 
+			gpx_t *gpx) {
 
   /* find end of cache chain */
   cache_t **cache = &gpx->cache;
@@ -941,7 +961,7 @@ static void process_loc(xmlTextReaderPtr reader, gpx_t *gpx) {
       char *name = (char*)xmlTextReaderConstName(reader);
 
       if(name && strcasecmp(name, "waypoint") == 0) {
-	*cache = process_loc_waypoint(reader);
+	*cache = process_loc_waypoint(reader, dialog);
 	if(*cache) cache = &(*cache)->next;
       } else
 	skip_element(reader);
@@ -963,7 +983,9 @@ static void process_loc(xmlTextReaderPtr reader, gpx_t *gpx) {
   return;
 }
 
-static gpx_t *process_root(xmlTextReaderPtr reader, char *fname, gpx_t *in) {
+static gpx_t *process_root(xmlTextReaderPtr reader, gpx_dialog_t *dialog, 
+			   char *fname, gpx_t *in) {
+
   /* no gpx entry given, create a new one */
   gpx_t *gpx = NULL;
   if(!in) {
@@ -981,9 +1003,9 @@ static gpx_t *process_root(xmlTextReaderPtr reader, char *fname, gpx_t *in) {
       g_assert(xmlTextReaderDepth(reader) == 0);
       char *name = (char*)xmlTextReaderConstName(reader);
       if(name && strcasecmp(name, "gpx") == 0) {
-	process_gpx(reader, gpx);
+	process_gpx(reader, dialog, gpx);
       } else if(name && strcasecmp(name, "loc") == 0) {
-	process_loc(reader, gpx);
+	process_loc(reader, dialog, gpx);
       } else {
 	printf("something unknown found\n");
 	skip_element(reader);
@@ -1017,14 +1039,16 @@ static gpx_t *process_root(xmlTextReaderPtr reader, char *fname, gpx_t *in) {
   return gpx;
 }
 
-static gpx_t *gpx_parse_file(char *filename) {
+static gpx_t *gpx_parse_file(gpx_dialog_t *dialog, char *filename) {
   gpx_t *gpx = NULL;
 
   LIBXML_TEST_VERSION;
 
+  gpx_busy_dialog_set(dialog, filename);
+
   xmlTextReaderPtr reader = xmlReaderForFile(filename, NULL, 0);
   if (reader != NULL) {
-    gpx = process_root(reader, filename, NULL);
+    gpx = process_root(reader, dialog, filename, NULL);
     xmlFreeTextReader(reader);
   } else {
     fprintf(stderr, "Unable to open %s\n", filename);
@@ -1042,7 +1066,7 @@ static gpx_t *gpx_parse_file(char *filename) {
 
       xmlTextReaderPtr reader = xmlReaderForFile(wpts_name, NULL, 0);
       if (reader != NULL) {
-	gpx = process_root(reader, wpts_name, gpx);
+	gpx = process_root(reader, dialog, wpts_name, gpx);
 	xmlFreeTextReader(reader);
       } else {
 	fprintf(stderr, "Unable to open %s\n", filename);
@@ -1053,11 +1077,14 @@ static gpx_t *gpx_parse_file(char *filename) {
   return gpx;
 }
 
-static gpx_t *decompress_file(unzFile file, char *name, char *filename,
+static gpx_t *decompress_file(unzFile file, gpx_dialog_t *dialog, 
+			      char *name, char *filename,
 			      gpx_t *gpx_in) {
   unz_file_info info;
   gpx_t *gpx = NULL;
   
+  gpx_busy_dialog_set(dialog, name);
+
   if((unzLocateFile(file, name, FALSE) != Z_OK) ||
      (unzGetCurrentFileInfo(file, &info, NULL,0, NULL,0, NULL,0) != Z_OK) ||
      (unzOpenCurrentFile(file) != UNZ_OK)) {
@@ -1096,7 +1123,7 @@ static gpx_t *decompress_file(unzFile file, char *name, char *filename,
     xmlReaderForMemory(buffer, info.uncompressed_size, 
 		       NULL, NULL, 0);
   if (reader != NULL) {
-    gpx = process_root(reader, filename, gpx_in);
+    gpx = process_root(reader, dialog, filename, gpx_in);
     xmlFreeTextReader(reader);
   } else {
     fprintf(stderr, "Unable to open %s\n", filename);
@@ -1107,7 +1134,7 @@ static gpx_t *decompress_file(unzFile file, char *name, char *filename,
   return gpx;
 }
 
-static gpx_t *decompress_zip(char *filename) {
+static gpx_t *decompress_zip(gpx_dialog_t *dialog, char *filename) {
   char *gpx_name, *fbase;
   gpx_t *gpx = NULL;
 
@@ -1131,39 +1158,49 @@ static gpx_t *decompress_zip(char *filename) {
   strcpy(gpx_name+strlen(gpx_name)-4, ".gpx");
   printf("gpx file name is %s\n", gpx_name);
 
-  gpx = decompress_file(file, gpx_name, filename, NULL);
+  gpx = decompress_file(file, dialog, gpx_name, filename, NULL);
 
   /* try to open -wpts.gpx file inside */
   strcpy(gpx_name, fbase);
   strcpy(gpx_name+strlen(gpx_name)-4, "-wpts.gpx");
   printf("gpx wpts file name is %s\n", gpx_name);
 
-  gpx = decompress_file(file, gpx_name, filename, gpx);
+  gpx = decompress_file(file, dialog, gpx_name, filename, gpx);
 
   unzClose(file);
   free(gpx_name);
   return gpx;
 }
 
-gpx_t *gpx_parse(char *filename) {
+gpx_t *gpx_parse(gpx_dialog_t *dialog, char *filename) {
+  gpx_t *gpx = NULL;
+
+  /* show busy dialog */
+  printf("load file %s\n", filename);
+
   if((strlen(filename) > 4) &&
      !strcasecmp(filename+strlen(filename)-4, ".zip")) {
     printf("trying to load a zip file!\n");
 
-    return decompress_zip(filename);
-  }
+    gpx = decompress_zip(dialog, filename);
+  } else 
+    gpx = gpx_parse_file(dialog, filename);
 
-  return gpx_parse_file(filename);
+  return gpx;
 }
 
 /* scan entire directory */
-gpx_t *gpx_parse_dir(char *dirname) {
+gpx_t *gpx_parse_dir(gpx_dialog_t *dialog, char *dirname) {
   GnomeVFSResult result;
   GnomeVFSDirectoryHandle *handle;
   GnomeVFSFileInfo *finfo = gnome_vfs_file_info_new();;
 
   gpx_t *gpx = NULL;
   
+  /* show busy dialog */
+  printf("load dir %s\n", dirname);
+  gpx_busy_dialog_set(dialog, dirname);
+
   LIBXML_TEST_VERSION;
 
   result = gnome_vfs_directory_open(&handle, dirname, 
@@ -1172,7 +1209,6 @@ gpx_t *gpx_parse_dir(char *dirname) {
   if(result != GNOME_VFS_OK) {
     errorf("Unable to open directory \"%s\":\n%s",
 	   dirname,  gnome_vfs_result_to_string(result));
-    
     return NULL;
   }
 
@@ -1191,7 +1227,7 @@ gpx_t *gpx_parse_dir(char *dirname) {
 
 	xmlTextReaderPtr reader = xmlReaderForFile(filename, NULL, 0);
 	if (reader != NULL) {
-	  gpx = process_root(reader, filename, gpx);
+	  gpx = process_root(reader, dialog, filename, gpx);
 	  xmlFreeTextReader(reader);
 	} else {
 	  fprintf(stderr, "Unable to open %s\n", filename);
