@@ -133,16 +133,20 @@ gpx_t *choose_file(appdata_t *appdata, gboolean whole_dir) {
   if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_FM_OK) {
     char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
+    gpx_dialog_t *dialog = gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
+
     if(!whole_dir) 
-      gpx = gpx_parse(filename);
+      gpx = gpx_parse(dialog, filename);
     else {
       /* cur trailing '/' if present */
       if(strlastchr(filename) == '/')
 	filename[strlen(filename)] = 0;
 
-      gpx = gpx_parse_dir(filename);
+      gpx = gpx_parse_dir(dialog, filename);
     }
 
+    gpx_busy_dialog_destroy(dialog);
+
     /* save path if gpx was successfully loaded */
     if(gpx) {
       char *r = strrchr(filename, '/');
@@ -427,6 +431,7 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 
       /* Append a row and fill in some data */
       gtk_list_store_append (store, &iter);
+
       gtk_list_store_set(store, &iter,
 			 CACHELIST_COL_TYPE, type,
 			 CACHELIST_COL_ID,   cache->id,
@@ -1719,25 +1724,6 @@ int main(int argc, char *argv[]) {
     g_error("Gnome VFS init failed\n");
   }
 
-  appdata.gconf_client = gconf_client_get_default();
-  gconf_load_state(&appdata);
-
-  gps_init(&appdata);
-
-  /* attach all gpx files given on command line */
-  if(argc >= 2) {
-    int i;
-    gpx_t **cur = &appdata.gpx;
-    while(*cur) cur = &((*cur)->next);
-
-    for(i=1;i<argc;i++) {
-      if((*cur = gpx_parse(argv[i])))
-	cur = &(*cur)->next;
-    }
-  }
-
-  //  gpx_display_all(gpx);
-
 #ifdef USE_MAEMO
   /* Create the hildon program and setup the title */
   appdata.program = HILDON_PROGRAM(hildon_program_get_instance());
@@ -1774,6 +1760,15 @@ int main(int argc, char *argv[]) {
   crumb_add(&appdata, "GPX", CRUMB_GPXLIST, NULL);
 #endif
 
+  /* wait for main gui to appear */
+  gtk_widget_show_all(GTK_WIDGET(appdata.window));
+  while(gtk_events_pending()) 
+    gtk_main_iteration();
+
+  appdata.gconf_client = gconf_client_get_default();
+  gconf_load_state(&appdata);
+  gps_init(&appdata);
+
   appdata.cur_view = gpxlist_create_view_and_model(&appdata, NULL);
   gtk_box_pack_start_defaults(GTK_BOX(appdata.vbox), appdata.cur_view);
 
