@@ -18,6 +18,8 @@
  */
 
 #include "gpxview.h"
+
+#include <math.h>
 #include <sqlite3.h>
 
 static const char *cache_type_icons[] = { 
@@ -66,7 +68,6 @@ char *escape(char *str) {
 
 /* export a single cache to the database */
 static void cache_export(sqlite3 *db, int id, cache_t *cache) {
-  int rc;
   char *zErrMsg = 0;
   char cmd[256];
 
@@ -216,15 +217,6 @@ typedef struct {
 #endif
 } export_context_t;
 
-/* a entry that is colored red when being "active" */
-static GtkWidget *gtk_red_entry_new(void) {
-  GdkColor color;
-  GtkWidget *widget = gtk_entry_new();
-  gdk_color_parse("#ff0000", &color);
-  gtk_widget_modify_text(widget, TAG_STATE, &color);
-  return widget;
-}
-
 static float distance_eval(GtkWidget *widget, export_context_t *context) {
   char *p = (char*)gtk_entry_get_text(GTK_ENTRY(widget));
   float val = distance_parse(p, context->appdata->imperial);
