@@ -18,6 +18,7 @@
  */
 
 #include "gpxview.h"
+#include <math.h>
 
 typedef struct {
   GtkWidget *cbox_gps;
@@ -426,7 +427,6 @@ static GtkWidget *location_widget(location_context_t *context) {
 		     -1);
 
   location_t *loc = context->appdata->location;
-  int cnt = 0;
   while(loc) {
     pos_lat_str(lat, sizeof(lat), loc->pos.lat);
     pos_lon_str(lon, sizeof(lon), loc->pos.lon);
@@ -492,7 +492,6 @@ void cb_menu_settings(GtkWidget *window, gpointer data) {
   GtkWidget *table, *label, *hbox, *notebook;
   GtkWidget *cbox_imperial, *cbox_load_images;
   settings_dialog_state_t hstate;
-  char str[32];
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Settings"),
 	    GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
@@ -671,9 +670,7 @@ void cb_menu_settings(GtkWidget *window, gpointer data) {
   gtk_widget_show_all(dialog);
 
   if(GTK_RESPONSE_ACCEPT == gtk_dialog_run(GTK_DIALOG(dialog))) {
-    gboolean prev_use_gps = appdata->use_gps;
     gboolean prev_cachelist_hide_found = appdata->cachelist_hide_found;
-    float prev_lat = appdata->home.lat, prev_lon = appdata->home.lon;
 
     appdata->use_gps = gtk_toggle_button_get_active(
 			    GTK_TOGGLE_BUTTON(hstate.cbox_gps));
@@ -716,16 +713,6 @@ void cb_menu_settings(GtkWidget *window, gpointer data) {
     /* redraw is necessary */
     int flags = CHANGE_FLAG_POS;
 
-#if 0
-    int flags = 0;
-    if(prev_use_gps != appdata->use_gps)
-      flags |= CHANGE_FLAG_POS;   // position has changed 
-
-    if(!appdata->use_gps && 
-       ((prev_lat != appdata->home.lat)||(prev_lon != appdata->home.lon))  )
-      flags |= CHANGE_FLAG_POS;   // position has changed 
-#endif
-
     if(prev_cachelist_hide_found != appdata->cachelist_hide_found)
       flags |= CHANGE_FLAG_MASK;   // visibility mask has changed 
 
